Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1480)

Unified Diff: content/public/renderer/render_view.h

Issue 165233003: Replace WebDocument::focusedNode to focusedElement (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix nits Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/renderer/render_view.h
diff --git a/content/public/renderer/render_view.h b/content/public/renderer/render_view.h
index c7ab4af97551a6ea8bbc42609c6f262bbd31e9ab..c3ce12ecc0a7ea9e4f25f1293bde2282f4a7c758 100644
--- a/content/public/renderer/render_view.h
+++ b/content/public/renderer/render_view.h
@@ -18,6 +18,7 @@
struct WebPreferences;
namespace blink {
+class WebElement;
class WebFrame;
class WebNode;
class WebString;
@@ -75,8 +76,9 @@ class CONTENT_EXPORT RenderView : public IPC::Sender {
// Returns the associated WebView. May return NULL when the view is closing.
virtual blink::WebView* GetWebView() = 0;
- // Gets the focused node. If no such node exists then the node will be isNull.
- virtual blink::WebNode GetFocusedNode() const = 0;
+ // Gets the focused element. If no such element exists then
+ // the element will be Null.
+ virtual blink::WebElement GetFocusedElement() const = 0;
// Gets the node that the context menu was pressed over.
virtual blink::WebNode GetContextMenuNode() const = 0;

Powered by Google App Engine
This is Rietveld 408576698